@@ -21,6 +21,7 @@
 
 #include "omx.h"
 #include "display.h"
+#include "setup.h"
 
 #include <vdr/tools.h>
 #include <vdr/thread.h>
@@ -31,8 +32,6 @@ extern "C" {
 
 #include "bcm_host.h"
 
-#define OMX_PRE_ROLL 0
-
 // default: 20x 81920 bytes, now 128x 64k (8M)
 #define OMX_VIDEO_BUFFERS 128
 #define OMX_VIDEO_BUFFERSIZE KILOBYTE(64);
@@ -206,9 +205,19 @@ void cOmx::Action(void)
 				break;
 
 			case cOmxEvents::eConfigChanged:
-				if (event->data == OMX_IndexConfigBufferStall)
+				switch (event->data)
+				{
+				case OMX_IndexParamBrcmPixelAspectRatio:
+					if (m_handlePortEvents)
+						HandlePortSettingsChanged(131);
+					break;
+				case OMX_IndexConfigBufferStall:
 					if (IsBufferStall() && !IsClockFreezed() && m_onBufferStall)
 						m_onBufferStall(m_onBufferStallData);
+					break;
+				default:
+					break;
+				}
 				break;
 
 			case cOmxEvents::eEndOfStream:
@@ -362,8 +371,11 @@ void cOmx::HandlePortSettingsChanged(unsigned int portId)
 
 		if (cRpiDisplay::IsProgressive() && m_videoFrameFormat.Interlaced())
 		{
-			bool fastDeinterlace = portdef.format.video.nFrameWidth *
-					portdef.format.video.nFrameHeight > 576 * 720;
+			bool fastDeinterlace = !cRpiSetup::UseAdvancedDeinterlacer(
+					portdef.format.video.nFrameWidth,
+					portdef.format.video.nFrameHeight);
+
+			DBG("using %s deinterlacer", fastDeinterlace ? "fast" : "advanced");
 
 			filterparam.nNumParams = 4;
 			filterparam.nParams[0] = 3;
@@ -551,6 +563,7 @@ int cOmx::Init(int display, int layer)
 
 	SetDisplay(display, layer);
 	SetClockLatencyTarget();
+	SetPARChangeCallback(true);
 	SetBufferStallThreshold(20000);
 	SetClockReference(cOmx::eClockRefVideo);
 
@@ -662,7 +675,7 @@ bool cOmx::IsClockRunning(void)
 		return false;
 }
 
-void cOmx::StartClock(bool waitForVideo, bool waitForAudio)
+void cOmx::StartClock(bool waitForVideo, bool waitForAudio, int preRollMs)
 {
 	DBG("StartClock(%svideo, %saudio)",
 			waitForVideo ? "" : "no ",
@@ -672,7 +685,7 @@ void cOmx::StartClock(bool waitForVideo, bool waitForAudio)
 	OMX_INIT_STRUCT(cstate);
 
 	cstate.eState = OMX_TIME_ClockStateRunning;
-	cstate.nOffset = ToOmxTicks(-1000LL * OMX_PRE_ROLL);
+	cstate.nOffset = ToOmxTicks(-1000LL * preRollMs);
 
 	if (waitForVideo)
 	{
@@ -698,7 +711,6 @@ void cOmx::StopClock(void)
 	OMX_INIT_STRUCT(cstate);
 
 	cstate.eState = OMX_TIME_ClockStateStopped;
-	cstate.nOffset = ToOmxTicks(-1000LL * OMX_PRE_ROLL);
 
 	if (OMX_SetConfig(ILC_GET_HANDLE(m_comp[eClock]),
 			OMX_IndexConfigTimeClockState, &cstate) != OMX_ErrorNone)
@@ -821,6 +833,18 @@ void cOmx::SetClockLatencyTarget(void)
 		ELOG("failed set video render latency target!");
 }
 
+void cOmx::SetPARChangeCallback(bool enable)
+{
+	OMX_CONFIG_REQUESTCALLBACKTYPE reqCallback;
+	OMX_INIT_STRUCT(reqCallback);
+	reqCallback.nPortIndex = 131;
+	reqCallback.bEnable = enable ? OMX_TRUE : OMX_FALSE;
+	reqCallback.nIndex = OMX_IndexParamBrcmPixelAspectRatio;
+	if (OMX_SetConfig(ILC_GET_HANDLE(m_comp[eVideoDecoder]),
+			OMX_IndexConfigRequestCallback, &reqCallback) != OMX_ErrorNone)
+		ELOG("failed to set video aspect ratio change call back!");
+}
+
 void cOmx::SetBufferStallThreshold(int delayMs)
 {
 	if (delayMs > 0)
