@@ -22,6 +22,7 @@
 #include "audio.h"
 #include "display.h"
 #include "setup.h"
+#include "tools.h"
 
 #include <vdr/thread.h>
 #include <vdr/remux.h>
@@ -33,6 +34,9 @@
 #define S(x) ((int)(floor(x * pow(2, 16))))
 #define PTS_START_OFFSET (32 * (MAX33BIT + 1))
 
+#define PRE_ROLL_LIVE 250
+#define PRE_ROLL_PLAYBACK 0
+
 // trick speeds as defined in vdr/dvbplayer.c
 const int cOmxDevice::s_playbackSpeeds[eNumDirections][eNumPlaybackSpeeds] = {
 	{ S(0.0f), S( 0.125f), S( 0.25f), S( 0.5f), S( 1.0f), S( 2.0f), S( 4.0f), S( 12.0f) },
@@ -289,7 +293,8 @@ int cOmxDevice::PlayAudio(const uchar *Data, int Length, uchar Id)
 				DBG("audio first");
 				m_omx->SetClockScale(
 						s_playbackSpeeds[m_direction][m_playbackSpeed]);
-				m_omx->StartClock(m_hasVideo, m_hasAudio);
+				m_omx->StartClock(m_hasVideo, m_hasAudio,
+						Transferring() ? PRE_ROLL_LIVE : PRE_ROLL_PLAYBACK);
 				m_audioPts = PTS_START_OFFSET + pts;
 				m_playMode = pmAudioOnly;
 			}
@@ -382,7 +387,8 @@ int cOmxDevice::PlayVideo(const uchar *Data, int Length, bool EndOfFrame)
 			DBG("video first");
 			m_omx->SetClockReference(cOmx::eClockRefVideo);
 			m_omx->SetClockScale(s_playbackSpeeds[m_direction][m_playbackSpeed]);
-			m_omx->StartClock(m_hasVideo, m_hasAudio);
+			m_omx->StartClock(m_hasVideo, m_hasAudio,
+					Transferring() ? PRE_ROLL_LIVE : PRE_ROLL_PLAYBACK);
 			m_videoPts = PTS_START_OFFSET + pts;
 			m_playMode = pmVideoOnly;
 		}
@@ -686,7 +692,8 @@ void cOmxDevice::HandleEndOfStream()
 	// flush pipes and restart clock after still image
 	FlushStreams();
 	m_omx->SetClockScale(s_playbackSpeeds[m_direction][m_playbackSpeed]);
-	m_omx->StartClock(m_hasVideo, m_hasAudio);
+	m_omx->StartClock(m_hasVideo, m_hasAudio,
+			Transferring() ? PRE_ROLL_LIVE : PRE_ROLL_PLAYBACK);
 
 	m_mutex->Unlock();
 }
@@ -696,18 +703,17 @@ void cOmxDevice::HandleStreamStart()
 	DBG("HandleStreamStart()");
 
 	const cVideoFrameFormat *format = m_omx->GetVideoFrameFormat();
-	DLOG("video stream started %dx%d@%d%s PAR(%d:%d)",
+	DLOG("video stream started %dx%d@%d%s, PAR=%d/%d",
 			format->width, format->height, format->frameRate,
 			format->Interlaced() ? "i" : "p",
 			format->pixelWidth, format->pixelHeight);
 
-	cRpiDisplay::SetVideoFormat(format);
+	HandleVideoSetupChanged();
 }
 
 void cOmxDevice::HandleVideoSetupChanged()
 {
-	DBG("HandleVideoSetupChanged()");
-
+	// apply framing parameters
 	switch (cRpiSetup::GetVideoFraming())
 	{
 	default:
@@ -724,7 +730,24 @@ void cOmxDevice::HandleVideoSetupChanged()
 		break;
 	}
 
-	cRpiDisplay::SetVideoFormat(m_omx->GetVideoFrameFormat());
+	const cVideoFrameFormat *format = m_omx->GetVideoFrameFormat();
+	double videoPAR = format->pixelHeight ?
+			(double)format->pixelWidth / format->pixelHeight : 1.0f;
+
+	// update display format according current video stream
+	cRpiDisplay::SetVideoFormat(format);
+
+	// get updated display format ...
+	int width, height;
+	double displayPAR;
+	cRpiDisplay::GetSize(width, height, displayPAR);
+
+	// ... and set video render format accordingly
+	cRational renderPAR = cRational(videoPAR / displayPAR);
+	renderPAR.Reduce(100);
+	m_omx->SetPixelAspectRatio(renderPAR.num, renderPAR.den);
+	DLOG("display PAR=%0.3f, setting video render PAR=%d/%d",
+			displayPAR, renderPAR.num, renderPAR.den);
 }
 
 void cOmxDevice::FlushStreams(bool flushVideoRender)
