@@ -757,6 +757,7 @@ public:
 
 	virtual bool Execute(cEgl *egl) = 0;
 	virtual const char* Description(void) = 0;
+	virtual bool IsFlush(void) { return false; };
 
 protected:
 
@@ -776,6 +777,7 @@ public:
 		cOvgCmd(target) { }
 
 	virtual const char* Description(void) { return "Flush"; }
+	virtual bool IsFlush(void) { return true; };
 
 	virtual bool Execute(cEgl *egl)
 	{
@@ -1207,14 +1209,14 @@ public:
 			if (m_alignment & taLeft)
 			{
 				if (m_alignment & taBorder)
-					offsetX += max(height / TEXT_ALIGN_BORDER, 1.0f);
+					offsetX += std::max(height / TEXT_ALIGN_BORDER, 1.0f);
 			}
 			else if (m_alignment & taRight)
 			{
 				if (width < m_w)
 					offsetX += m_w - width;
 				if (m_alignment & taBorder)
-					offsetX -= max(height / TEXT_ALIGN_BORDER, 1.0f);
+					offsetX -= std::max(height / TEXT_ALIGN_BORDER, 1.0f);
 			}
 			else
 			{
@@ -1240,12 +1242,9 @@ public:
 		vgSeti(VG_BLEND_MODE, VG_BLEND_SRC);
 		vgSeti(VG_MATRIX_MODE, VG_MATRIX_GLYPH_USER_TO_SURFACE);
 
-		// some magic offset to conform with VDR's text rendering
-		offsetY -= 0.06f * m_fontSize;
-
 		vgLoadIdentity();
 		vgTranslate(m_x + offsetX,
-				m_target->height - m_y - m_fontSize - offsetY + 1);
+				m_target->height - m_y - height + descender - offsetY + 1);
 		vgScale(m_fontSize, m_fontSize);
 
 		VGfloat origin[2] = { 0.0f, 0.0f };
@@ -1253,10 +1252,11 @@ public:
 
 		cOvgPaintBox::SetScissoring(
 				m_w ? m_x : m_x + floor(offsetX),
-				m_h ? m_target->height - m_y - m_h : m_target->height - m_y -
-						m_fontSize - floor(descender) + 1,
-				m_w ? m_w : floor(width) + 1,
-				m_h ? m_h : m_fontSize + floor(descender) - 1);
+				m_h ? m_target->height - m_y - m_h :
+						m_target->height - m_y - floor(height),
+				m_w ? m_w : floor(width),
+				m_h ? m_h : floor(height));
+
 
 		if (m_colorBg != clrTransparent)
 		{
@@ -1592,8 +1592,8 @@ public:
 
 	virtual bool Execute(cEgl *egl)
 	{
-		int w = min(m_w, vgGeti(VG_MAX_IMAGE_WIDTH));
-		int h = min(m_h, vgGeti(VG_MAX_IMAGE_HEIGHT));
+		int w = std::min(m_w, vgGeti(VG_MAX_IMAGE_WIDTH));
+		int h = std::min(m_h, vgGeti(VG_MAX_IMAGE_HEIGHT));
 
 		if (w <= 0 || h <= 0)
 			return true;
@@ -1866,6 +1866,11 @@ protected:
 			vgSetfv(VG_CLEAR_COLOR, 4, color);
 			vgClear(0, 0, egl.window.width, egl.window.height);
 
+#ifdef DEBUG_OVGSTAT
+			cTimeMs timer;
+			int commands = 0, flushes = 0;
+#endif
+
 			bool reset = false;
 			while (!reset)
 			{
@@ -1878,6 +1883,22 @@ protected:
 					m_commands.pop();
 					Unlock();
 
+#ifdef DEBUG_OVGSTAT
+					if (timer.TimedOut())
+					{
+						if (commands || flushes)
+						{
+							DLOG("[OpenVG] commands executed: %d, flushes: %d",
+									commands, flushes);
+							commands = 0;
+							flushes = 0;
+						}
+						timer.Set(1000);
+					}
+					commands++;
+					if (cmd->IsFlush())
+						flushes++;
+#endif
 					reset = cmd ? !cmd->Execute(&egl) : true;
 
 					VGErrorCode err = vgGetError();
@@ -2120,13 +2141,18 @@ public:
 			return;
 
 		if (len)
+		{
 			Utf8ToArray(s, symbols, len + 1);
-		else
-			symbols[0] = 0;
-
-		m_ovg->DoCmd(new cOvgCmdDrawText(m_buffer, Point.X(), Point.Y(),
+			m_ovg->DoCmd(new cOvgCmdDrawText(m_buffer, Point.X(), Point.Y(),
 				symbols, new cString(Font->FontName()), Font->Size(),
 				ColorFg, ColorBg, Width, Height, Alignment));
+		}
+		else
+		{
+			if (Width && Height)
+				m_ovg->DoCmd(new cOvgCmdDrawRectangle(m_buffer,
+					Point.X(), Point.Y(), Width, Height, ColorBg));
+		}
 
 		SetDirty();
 		MarkDrawPortDirty(cRect(Point.X(), Point.Y(),
@@ -2354,11 +2380,11 @@ public:
 		{
 			ELOG("[OpenVG] cannot allocate pixmap of %dpx x %dpx, "
 					"clipped to %dpx x %dpx!", width, height,
-					min(width, m_ovg->MaxImageSize().Width()),
-					min(height, m_ovg->MaxImageSize().Height()));
+					std::min(width, m_ovg->MaxImageSize().Width()),
+					std::min(height, m_ovg->MaxImageSize().Height()));
 
-			width = min(width, m_ovg->MaxImageSize().Width());
-			height = min(height, m_ovg->MaxImageSize().Height());
+			width = std::min(width, m_ovg->MaxImageSize().Width());
+			height = std::min(height, m_ovg->MaxImageSize().Height());
 		}
 #endif
 		// create pixel buffer and wait until command has been completed
